==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mainmenu/translations/mainmenu_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>RazorMainMenu</name>
    <message>
        <location filename="../razormainmenu.cpp" line="178"/>
        <source>Leave</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="14"/>
        <source>Razor Main Menu settings</source>
        <translation>Impostazioni Menu Principale</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generali</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Mostra testo</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="45"/>
        <source>Button text</source>
        <translation>Testo del pulsante</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="65"/>
        <location filename="../razormainmenuconfiguration.ui" line="71"/>
        <source>Menu file</source>
        <translation>File del menu</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="85"/>
        <source>...</source>
        <translation>Scegli...</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="95"/>
        <source>Keyboard Shortcut</source>
        <translation>Scorciatoie da tastiera</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="101"/>
        <source>Click the button to record shortcut:</source>
        <translation>Clicca sul bottone per registrare una scorciatoia:</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="89"/>
        <source>Choose menu file</source>
        <translation>Scegli file di menu</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="89"/>
        <source>Menu files (*.menu)</source>
        <translation>Files di menu (*.menu)</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mainmenu/translations/mainmenu_it_IT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>RazorMainMenu</name>
    <message>
        <source>Leave</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <source>Razor Main Menu settings</source>
        <translation>Impostazioni del menu principale di Razor</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation>Mostra testo</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation>Testo del pulsante</translation>
    </message>
    <message>
        <source>Menu file</source>
        <translation>File del menu</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Keyboard Shortcut</source>
        <translation>Scorciatoie da tastiera</translation>
    </message>
    <message>
        <source>Click the button to record shortcut:</source>
        <translation>Fai clic sul pulsante per registrare una scorciatoia:</translation>
    </message>
    <message>
        <source>Choose menu file</source>
        <translation>Scegli il file del menu</translation>
    </message>
    <message>
        <source>Menu files (*.menu)</source>
        <translation>File del menu (*.menu)</translation>
    </message>
</context>
</TS>
